@@ -10,7 +10,7 @@
 #   Craig Barratt  <cbarratt@users.sourceforge.net>
 #
 # COPYRIGHT
-#   Copyright (C) 2004-2017  Craig Barratt
+#   Copyright (C) 2004-2020  Craig Barratt
 #
 #   This program is free software: you can redistribute it and/or modify
 #   it under the terms of the GNU General Public License as published by
@@ -27,7 +27,7 @@
 #
 #========================================================================
 #
-# Version 4.1.5, released 3 Dec 2017.
+# Version 4.3.2, released 17 Feb 2020.
 #
 # See http://backuppc.sourceforge.net.
 #
@@ -89,6 +89,7 @@ use vars qw(%ConfigMeta);
     Ping6Path	 	=> {type => "execPath", undefIfEmpty => 1},
     DfPath	 	=> {type => "execPath", undefIfEmpty => 1},
     DfCmd	 	=> "string",
+    DfInodeUsageCmd	=> "string",
     SplitPath	 	=> {type => "execPath", undefIfEmpty => 1},
     ParPath	 	=> {type => "execPath", undefIfEmpty => 1},
     CatPath	 	=> {type => "execPath", undefIfEmpty => 1},
@@ -96,6 +97,7 @@ use vars qw(%ConfigMeta);
     Bzip2Path	 	=> {type => "execPath", undefIfEmpty => 1},
     RrdToolPath	 	=> {type => "execPath", undefIfEmpty => 1},
     DfMaxUsagePct	=> "float",
+    DfMaxInodeUsagePct	=> "float",
     DHCPAddressRanges   => {
             type    => "list",
 	    emptyOk => 1,
@@ -201,6 +203,13 @@ use vars qw(%ConfigMeta);
 
     ClientCharset       => "string",
     ClientCharsetLegacy => "string",
+    ClientShareName2Path => {
+            type      => "hash",
+	    keyText   => "CfgEdit_Button_New_Share",
+            emptyOk   => 1,
+            childType => "string",
+    },
+
     RefCntFsck          => "integer",
 
     ######################################################################
@@ -276,6 +285,11 @@ use vars qw(%ConfigMeta);
 	    emptyOk      => 1,
 	    child        => "string",
     },
+    RsyncIncrArgsExtra	 => {
+	    type         => "list",
+	    emptyOk      => 1,
+	    child        => "string",
+    },
 
     ######################################################################
     # FTP Configuration
@@ -309,6 +323,7 @@ use vars qw(%ConfigMeta);
     ######################################################################
     NmbLookupCmd 	=> "string",
     NmbLookupFindHostCmd => "string",
+    ClientComment       => "string",
 
     FixedIPNetBiosNameCheck => "boolean",
     PingCmd	 	=> "string",
@@ -345,6 +360,7 @@ use vars qw(%ConfigMeta);
     EMailNotifyMinDays        => "float",
     EMailFromUserName         => "string",
     EMailAdminUserName        => "string",
+    EMailAdminSubject         => "string",
     EMailUserDestDomain       => "string",
     EMailNoBackupEverSubj     => {type => "string",    undefIfEmpty => 1},
     EMailNoBackupEverMesg     => {type => "bigstring", undefIfEmpty => 1},
@@ -407,6 +423,7 @@ use vars qw(%ConfigMeta);
         },
     CgiImageDirURL 	=> "string",
     CgiCSSFile	 	=> "string",
+    CgiUserDeleteBackupEnable => "integer",
     CgiUserConfigEditEnable => "boolean",
     CgiUserConfigEdit   => {
 	    type => "hash",
@@ -434,6 +451,7 @@ use vars qw(%ConfigMeta);
                 XferLogLevel              => "boolean",
                 ClientCharset             => "boolean",
                 ClientCharsetLegacy       => "boolean",
+                ClientShareName2Path      => "boolean",
                 RefCntFsck                => "boolean",
                 SmbShareName              => "boolean",
                 SmbShareUserName          => "boolean",
@@ -453,11 +471,11 @@ use vars qw(%ConfigMeta);
                 RsyncdClientPort          => "boolean",
                 RsyncdUserName            => "boolean",
                 RsyncdPasswd              => "boolean",
-                RsyncdAuthRequired        => "boolean",
                 RsyncArgs                 => "boolean",
                 RsyncArgsExtra            => "boolean",
                 RsyncRestoreArgs          => "boolean",
                 RsyncFullArgsExtra        => "boolean",
+                RsyncIncrArgsExtra        => "boolean",
                 RsyncSshArgs              => "boolean",
                 RsyncClientPath           => "boolean",
                 FtpShareName              => "boolean",
@@ -482,6 +500,7 @@ use vars qw(%ConfigMeta);
                 MaxOldPerPCLogFiles       => "boolean",
                 CompressLevel             => "boolean",
                 ClientNameAlias           => "boolean",
+                ClientComment             => "boolean",
                 DumpPreUserCmd            => "boolean",
                 DumpPostUserCmd           => "boolean",
                 RestorePreUserCmd         => "boolean",
@@ -493,6 +512,7 @@ use vars qw(%ConfigMeta);
                 UserCmdCheckStatus        => "boolean",
                 EMailNotifyMinDays        => "boolean",
                 EMailFromUserName         => "boolean",
+                EMailAdminSubject         => "boolean",
                 EMailAdminUserName        => "boolean",
                 EMailUserDestDomain       => "boolean",
                 EMailNoBackupEverSubj     => "boolean",
